@@ -33,6 +33,8 @@ class HvcsBase:
     checking for NotImplemented around every method call.
     """
 
+    DEFAULT_ENV_TOKEN_NAME = "HVCS_TOKEN"
+
     def __init__(
         self,
         remote_url: str,
@@ -95,7 +97,7 @@ class HvcsBase:
 
     def get_release_id_by_tag(self, tag: str) -> int | None:
         """
-        Given a Git tag, return the ID (as the remote VCS defines it) of a corrsponding
+        Given a Git tag, return the ID (as the remote VCS defines it) of a corresponding
         release in the remove VCS, if supported
         """
         _not_supported(self, "get_release_id_by_tag")
@@ -125,7 +127,7 @@ class HvcsBase:
         return None
 
     def upload_asset(
-        self, release_id: int, file: str, label: str | None = None
+        self, release_id: int | str, file: str, label: str | None = None
     ) -> bool:
         """
         Upload an asset (file) to a release with the given release_id, if releases are
