@@ -38,6 +38,10 @@ class Gitlab(HvcsBase):
     API domain
     """
 
+    DEFAULT_ENV_TOKEN_NAME = "GITLAB_TOKEN"
+    # purposefully not CI_JOB_TOKEN as it is not a personal access token,
+    # It is missing the permission to push to the repository, but has all others (releases, packages, etc.)
+
     DEFAULT_DOMAIN = "gitlab.com"
 
     def __init__(
@@ -81,7 +85,10 @@ class Gitlab(HvcsBase):
 
     @logged_function(log)
     def create_release(
-        self, tag: str, release_notes: str, prerelease: bool = False  # noqa: ARG002
+        self,
+        tag: str,
+        release_notes: str,
+        prerelease: bool = False,  # noqa: ARG002
     ) -> str:
         """
         Post release changelog
